@@ -215,7 +215,7 @@ na.coverage <- function(..., data = NULL, tri = c("both", "lower", "upper"), dig
       # Send R output to textfile
       sink(file = write, append = ifelse(isTRUE(file.exists(write)), append, FALSE), type = "output", split = FALSE)
 
-      if (append && isTRUE(file.exists(write))) { write("", file = write, append = TRUE) }
+      if (isTRUE(append && file.exists(write))) { write("", file = write, append = TRUE) }
 
       # Print object
       print(object, check = FALSE)
